@@ -63,8 +63,7 @@ class MACAddressField(models.Field):
             return 'BigIntegerField'
         return 'CharField'
 
-    # @todo: remove context parameter when facing out django < 2.0 support
-    def from_db_value(self, value, expression, connection, context=None):
+    def from_db_value(self, value, expression, connection):
         return self.to_python(value)
 
     def to_python(self, value):
@@ -76,8 +75,7 @@ class MACAddressField(models.Field):
         try:
             return EUI(value, version=48, dialect=default_dialect())
         except (TypeError, ValueError, AddrFormatError):
-            raise ValidationError(
-                "This value must be a valid MAC address.")
+            raise ValidationError("This value must be a valid MAC address.")
 
     def formfield(self, **kwargs):
         defaults = {'form_class': MACAddressFormField}
@@ -86,7 +84,7 @@ class MACAddressField(models.Field):
 
     def get_prep_lookup(self, lookup_type, value):
         # data is stored internally as integer so searching as string
-        # yeild 0 result. for example: useful for search in admin.
+        # yield 0 result. for example: useful for search in admin.
         if lookup_type in ('exact', 'iexact', 'icontains', 'icontains'):
             try:
                 return self.get_prep_value(value)
@@ -102,13 +100,3 @@ class MACAddressField(models.Field):
                 return None
         else:
             raise TypeError('Lookup type %r not supported.' % lookup_type)
-
-if django.VERSION < (1, 8):
-    from django.utils.six import add_metaclass
-    MACAddressField = add_metaclass(models.SubfieldBase)(MACAddressField)
-
-try:
-    from south.modelsinspector import add_introspection_rules
-    add_introspection_rules([], ["^macaddress\.fields\.MACAddressField"])
-except ImportError:
-    pass
